# `reconner.dataset.Dataset`

`reconner.dataset.Dataset` is a container to run other `reconner` operations across your train/dev/test split
The `reconner.dataset.Dataset.apply` function takes any of the other reconner functions and runs them
on all the datasets in sequence.

---
## API

::: reconner.Dataset
    :docstring:
    :members:
